import * as sfn from '@aws-cdk/aws-stepfunctions';
import * as cdk from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface StateMachineApiGatewayExampleProps {
    /**
     * A stage name for the rest api.
     *
     * @default 'default'
     * @stability stable
     */
    readonly stageName: string;
    /**
     * The path part for the resource.
     *
     * @default 'pets'
     * @stability stable
     */
    readonly partPath: string;
}
/**
 * Converted from an AWS Blog post.
 *
 * It is the first example mentioned in https://aws.amazon.com/tw/blogs/compute/introducing-amazon-api-gateway-service-integration-for-aws-step-functions/.
 * This constcut will create an API Gateway Rest API with two methods and
 * are manipulated by a state machine managed in AWS StepFucntions.
 *
 * @stability stable
 */
export declare class StateMachineApiGatewayExample extends cdk.Construct {
    /**
     * sample input to start execution for the workflow.
     *
     * @stability stable
     */
    readonly executionInput: string;
    /**
     * the representation of a state machine.
     *
     * @stability stable
     */
    readonly stateMachine: sfn.StateMachine;
    /**
     * @stability stable
     */
    constructor(parent: cdk.Construct, name: string, props: StateMachineApiGatewayExampleProps);
    /**
       * Creates an API Gateway Rest API.
       *
       * @param stageName A stage name for the rest api
       * @param partPath The path part for the resource
       * @returns a rest api.
       */
    private _createRestApi;
    /**
       * Creates an IAM role for Step Functions.
       *
       * @param restApi The rest APIs for adding and storing pets.
       * @param stageName The stage name for the rest api
       * @param partPath The path part for the resource
       * @returns an IAM role for Step Functions.
       */
    private _createWorkFlowRole;
    /**
     * Creates a workflow.
     *
     * @param executionRole an IAM role for StepFunctions to execute Rest APIs.
     * @param restApi The rest APIs for adding and storing pets.
     * @param stageName The stage name for the rest api.
     * @param partPath The path part for the resource.
     * @returns a state machine.
     */
    private _createStateMachine;
}
